package com.nantian.cloud.dbcapp.carbon.service.impl;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.nantian.cloud.dbcapp.carbon.domain.InstrumentInfo;
import com.nantian.cloud.dbcapp.carbon.domain.carbonAccount.*;
import com.nantian.cloud.dbcapp.carbon.mapper.InstrumentDao;
import com.nantian.cloud.dbcapp.carbon.service.InstrumentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class InstrumentServiceImpl extends ServiceImpl<InstrumentDao, InstrumentInfo> implements InstrumentService {

    @Autowired
    private InstrumentDao instrumentDao;

    @Override
    public List<InstrumentDetailVo> getMeasurementList(String entId) {

        List<InstrumentDetailVo> instrumentInfos= instrumentDao.getMeasurementList(entId);
        return instrumentInfos;
    }

    @Override
    public IPage<EntInstrumentVo> selectEntList(Page page, String entName, String industryCode, Long level, String regionCode) {
        return instrumentDao.selectEntList(page,entName,industryCode,level,regionCode);
    }

    @Override
    public List<EntInstrumentVo> selectEntListBySumList( String entName, String industryCode, Long level, String regionCode) {
        return instrumentDao.selectEntListBySumList(entName,industryCode,level,regionCode);
    }

    @Override
    public List<InstrumentLevel> selectLevelList() {
        return instrumentDao.selectLevelList();
    }

    @Override
    public List<InstrumentCategory> selectCategoryList() {
        return instrumentDao.selectCategoryList();
    }

    @Override
    public List<EntConsumeType> selectEntConsumeTypeList() {
        return instrumentDao.selectEntConsumeTypeList();
    }

}
